@@ -36,7 +36,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CloneDB", params)
+            headers = request.headers
+            body = self.call("CloneDB", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CloneDBResponse()
@@ -64,7 +65,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateAccount", params)
+            headers = request.headers
+            body = self.call("CreateAccount", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateAccountResponse()
@@ -92,7 +94,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateBackup", params)
+            headers = request.headers
+            body = self.call("CreateBackup", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateBackupResponse()
@@ -120,7 +123,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateBackupMigration", params)
+            headers = request.headers
+            body = self.call("CreateBackupMigration", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateBackupMigrationResponse()
@@ -148,7 +152,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateDB", params)
+            headers = request.headers
+            body = self.call("CreateDB", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateDBResponse()
@@ -176,7 +181,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateDBInstances", params)
+            headers = request.headers
+            body = self.call("CreateDBInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateDBInstancesResponse()
@@ -204,7 +210,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateIncrementalMigration", params)
+            headers = request.headers
+            body = self.call("CreateIncrementalMigration", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateIncrementalMigrationResponse()
@@ -232,7 +239,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateMigration", params)
+            headers = request.headers
+            body = self.call("CreateMigration", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateMigrationResponse()
@@ -260,7 +268,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteAccount", params)
+            headers = request.headers
+            body = self.call("DeleteAccount", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteAccountResponse()
@@ -288,7 +297,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteBackupMigration", params)
+            headers = request.headers
+            body = self.call("DeleteBackupMigration", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteBackupMigrationResponse()
@@ -316,7 +326,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteDB", params)
+            headers = request.headers
+            body = self.call("DeleteDB", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteDBResponse()
@@ -344,7 +355,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteIncrementalMigration", params)
+            headers = request.headers
+            body = self.call("DeleteIncrementalMigration", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteIncrementalMigrationResponse()
@@ -372,7 +384,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteMigration", params)
+            headers = request.headers
+            body = self.call("DeleteMigration", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteMigrationResponse()
@@ -400,7 +413,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAccounts", params)
+            headers = request.headers
+            body = self.call("DescribeAccounts", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeAccountsResponse()
@@ -428,7 +442,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeBackupCommand", params)
+            headers = request.headers
+            body = self.call("DescribeBackupCommand", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeBackupCommandResponse()
@@ -456,7 +471,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeBackupFiles", params)
+            headers = request.headers
+            body = self.call("DescribeBackupFiles", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeBackupFilesResponse()
@@ -484,7 +500,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeBackupMigration", params)
+            headers = request.headers
+            body = self.call("DescribeBackupMigration", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeBackupMigrationResponse()
@@ -512,7 +529,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeBackupUploadSize", params)
+            headers = request.headers
+            body = self.call("DescribeBackupUploadSize", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeBackupUploadSizeResponse()
@@ -540,7 +558,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeBackups", params)
+            headers = request.headers
+            body = self.call("DescribeBackups", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeBackupsResponse()
@@ -568,7 +587,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDBCharsets", params)
+            headers = request.headers
+            body = self.call("DescribeDBCharsets", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDBCharsetsResponse()
@@ -596,7 +616,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDBInstances", params)
+            headers = request.headers
+            body = self.call("DescribeDBInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDBInstancesResponse()
@@ -624,7 +645,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDBs", params)
+            headers = request.headers
+            body = self.call("DescribeDBs", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDBsResponse()
@@ -652,7 +674,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDBsNormal", params)
+            headers = request.headers
+            body = self.call("DescribeDBsNormal", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDBsNormalResponse()
@@ -680,7 +703,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeFlowStatus", params)
+            headers = request.headers
+            body = self.call("DescribeFlowStatus", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeFlowStatusResponse()
@@ -708,7 +732,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeIncrementalMigration", params)
+            headers = request.headers
+            body = self.call("DescribeIncrementalMigration", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeIncrementalMigrationResponse()
@@ -736,7 +761,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeInstanceParamRecords", params)
+            headers = request.headers
+            body = self.call("DescribeInstanceParamRecords", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeInstanceParamRecordsResponse()
@@ -764,7 +790,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeInstanceParams", params)
+            headers = request.headers
+            body = self.call("DescribeInstanceParams", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeInstanceParamsResponse()
@@ -792,7 +819,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeMigrationDetail", params)
+            headers = request.headers
+            body = self.call("DescribeMigrationDetail", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeMigrationDetailResponse()
@@ -820,7 +848,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeMigrations", params)
+            headers = request.headers
+            body = self.call("DescribeMigrations", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeMigrationsResponse()
@@ -848,7 +877,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeOrders", params)
+            headers = request.headers
+            body = self.call("DescribeOrders", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeOrdersResponse()
@@ -876,7 +906,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeProductConfig", params)
+            headers = request.headers
+            body = self.call("DescribeProductConfig", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeProductConfigResponse()
@@ -904,7 +935,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeRegions", params)
+            headers = request.headers
+            body = self.call("DescribeRegions", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeRegionsResponse()
@@ -932,7 +964,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeRollbackTime", params)
+            headers = request.headers
+            body = self.call("DescribeRollbackTime", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeRollbackTimeResponse()
@@ -960,7 +993,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeSlowlogs", params)
+            headers = request.headers
+            body = self.call("DescribeSlowlogs", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeSlowlogsResponse()
@@ -988,7 +1022,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeUploadBackupInfo", params)
+            headers = request.headers
+            body = self.call("DescribeUploadBackupInfo", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeUploadBackupInfoResponse()
@@ -1016,7 +1051,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeZones", params)
+            headers = request.headers
+            body = self.call("DescribeZones", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeZonesResponse()
@@ -1044,7 +1080,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("InquiryPriceCreateDBInstances", params)
+            headers = request.headers
+            body = self.call("InquiryPriceCreateDBInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.InquiryPriceCreateDBInstancesResponse()
@@ -1072,7 +1109,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("InquiryPriceUpgradeDBInstance", params)
+            headers = request.headers
+            body = self.call("InquiryPriceUpgradeDBInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.InquiryPriceUpgradeDBInstanceResponse()
@@ -1100,7 +1138,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyAccountPrivilege", params)
+            headers = request.headers
+            body = self.call("ModifyAccountPrivilege", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyAccountPrivilegeResponse()
@@ -1128,7 +1167,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyAccountRemark", params)
+            headers = request.headers
+            body = self.call("ModifyAccountRemark", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyAccountRemarkResponse()
@@ -1156,7 +1196,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyBackupMigration", params)
+            headers = request.headers
+            body = self.call("ModifyBackupMigration", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyBackupMigrationResponse()
@@ -1184,7 +1225,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyBackupStrategy", params)
+            headers = request.headers
+            body = self.call("ModifyBackupStrategy", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyBackupStrategyResponse()
@@ -1212,7 +1254,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDBInstanceName", params)
+            headers = request.headers
+            body = self.call("ModifyDBInstanceName", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDBInstanceNameResponse()
@@ -1240,7 +1283,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDBInstanceNetwork", params)
+            headers = request.headers
+            body = self.call("ModifyDBInstanceNetwork", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDBInstanceNetworkResponse()
@@ -1268,7 +1312,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDBInstanceProject", params)
+            headers = request.headers
+            body = self.call("ModifyDBInstanceProject", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDBInstanceProjectResponse()
@@ -1296,7 +1341,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDBName", params)
+            headers = request.headers
+            body = self.call("ModifyDBName", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDBNameResponse()
@@ -1324,7 +1370,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDBRemark", params)
+            headers = request.headers
+            body = self.call("ModifyDBRemark", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDBRemarkResponse()
@@ -1352,7 +1399,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDatabaseCDC", params)
+            headers = request.headers
+            body = self.call("ModifyDatabaseCDC", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDatabaseCDCResponse()
@@ -1380,7 +1428,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDatabaseCT", params)
+            headers = request.headers
+            body = self.call("ModifyDatabaseCT", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDatabaseCTResponse()
@@ -1408,7 +1457,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDatabaseMdf", params)
+            headers = request.headers
+            body = self.call("ModifyDatabaseMdf", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDatabaseMdfResponse()
@@ -1436,7 +1486,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyIncrementalMigration", params)
+            headers = request.headers
+            body = self.call("ModifyIncrementalMigration", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyIncrementalMigrationResponse()
@@ -1466,7 +1517,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyInstanceParam", params)
+            headers = request.headers
+            body = self.call("ModifyInstanceParam", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyInstanceParamResponse()
@@ -1494,7 +1546,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyMigration", params)
+            headers = request.headers
+            body = self.call("ModifyMigration", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyMigrationResponse()
@@ -1522,7 +1575,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("RecycleDBInstance", params)
+            headers = request.headers
+            body = self.call("RecycleDBInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.RecycleDBInstanceResponse()
@@ -1550,7 +1604,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ResetAccountPassword", params)
+            headers = request.headers
+            body = self.call("ResetAccountPassword", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ResetAccountPasswordResponse()
@@ -1578,7 +1633,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("RestartDBInstance", params)
+            headers = request.headers
+            body = self.call("RestartDBInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.RestartDBInstanceResponse()
@@ -1606,7 +1662,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("RestoreInstance", params)
+            headers = request.headers
+            body = self.call("RestoreInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.RestoreInstanceResponse()
@@ -1634,7 +1691,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("RollbackInstance", params)
+            headers = request.headers
+            body = self.call("RollbackInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.RollbackInstanceResponse()
@@ -1662,7 +1720,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("RunMigration", params)
+            headers = request.headers
+            body = self.call("RunMigration", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.RunMigrationResponse()
@@ -1690,7 +1749,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("StartBackupMigration", params)
+            headers = request.headers
+            body = self.call("StartBackupMigration", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.StartBackupMigrationResponse()
@@ -1718,7 +1778,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("StartIncrementalMigration", params)
+            headers = request.headers
+            body = self.call("StartIncrementalMigration", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.StartIncrementalMigrationResponse()
@@ -1746,7 +1807,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("TerminateDBInstance", params)
+            headers = request.headers
+            body = self.call("TerminateDBInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.TerminateDBInstanceResponse()
@@ -1774,7 +1836,8 @@ class SqlserverClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpgradeDBInstance", params)
+            headers = request.headers
+            body = self.call("UpgradeDBInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UpgradeDBInstanceResponse()
